Core
====

This directory is intended to define core functionality for this
module that is unrelated to the Django application framework.

In general, classes in this submodule provide basic functions useable
by command line scripts and can also be leveraged by application
framework addons.

Typical functionality provided here includes:

* Establishing connections to remote devices
* Normalization of data from a remote data source
* Computation and low-level analysis
